# LineItemData


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**amount** | **float** |  | [optional] 
**aria_invoice_id** | [**LineItemDataReadOnlyInvoiceId**](LineItemDataReadOnlyInvoiceId.md) |  | [optional] 
**client_service_id** | **str** |  | [optional] 
**credit_coupon_code** | **str, none_type** |  | [optional] 
**description** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**line_number** | **int** |  | [optional] 
**plan_name** | **str** |  | [optional] 
**plan_no** | **float** |  | [optional] 
**rate_per_unit** | **float** |  | [optional] 
**rate_schedule_no** | **float, none_type** |  | [optional] 
**rate_schedule_tier_no** | **float, none_type** |  | [optional] 
**service_name** | **str** |  | [optional] 
**service_no** | **float** |  | [optional] 
**units** | **float** |  | [optional] 
**usage_type_cd** | **str, none_type** |  | [optional] 
**usage_type_no** | **float, none_type** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


